/************************************************************
*  kernel.c - Device driver for Oregon Microsystem's pc38.
*  NASA IRTF
*  2680 Woodlawn Drive, Honolulu, HI, 96822
*
*  Author: Tony Denault
*************************************************************/

#include <conf.h>
#include <kernel.h>
#include <file.h>
#include <dldd.h>

#include "/sys/dheaders/pc38info.h"
#include "proto.h"

/*------------------------------------------------------------
**  read/write  a 8-bit word from I/O port
**------------------------------------------------------------
*/
#if ANSI
int PC38_inp8( short port )
{ }
#else
int PC38_inp8(port)
   short port;
{
   asm {
      xor   eax, eax
      mov   DX, port[EBP]
      in    AL, DX
   }
}
#endif
 
#if ANSI
int PC38_outp8( short port, short data)
{ }
#else
int PC38_outp8(port, data)
short port, data;
{
   asm {
      movzx  eax, data[EBP]
      movzx  edx, port[EBP]
      out    DX, AL
   }
}
#endif

/*--------------------------------------------------------------
**  PC38csleep() - a sleep function in units of 1/100 seconds.
**                csec = 1 means sleep for 0.01 seconds.
**--------------------------------------------------------------
*/
#if ANSI
int PC38csleep( int csec )
#else
int PC38csleep( csec )
   int csec;
#endif
{
   int *wakeup;
 
   wakeup = (int *) sysbrk(sizeof(int));
   *wakeup = 0;
   timeout(PC38csleeph, wakeup, csec);
   swait(wakeup, 0);
   sysfree(wakeup);
}
 
#if ANSI
int PC38csleeph( int * s )
#else
int PC38csleeph( s )
   int *s;
#endif
{
   ssignal(s);
}
 
/*-----------------------------------------------------------------------
**  PC38_puts() - writes a string to the the PC38
**-----------------------------------------------------------------------
*/
#if ANSI
int PC38_puts( int addr, char *mess )
#else
int PC38_puts( addr, mess )
   int  addr;
   char *mess;
#endif
{
	int loop;

	/* PC38_outp8(addr+PC38_CONTROL_REG,0); */
   while( *mess )
	{
		loop = 50;
		while( (PC38_inp8(addr+PC38_STATUS_REG) & PC38_TBE_BIT) == 0)
		{
			loop--;
			if(loop==1) PC38csleep(1);
			if(loop==0) return ERR_TIMEOUT;
		}
		PC38_outp8(addr+PC38_DATA_REG,*mess);
		mess++;
	}
	return ERR_NONE;
}

/*-----------------------------------------------------------------------
**  PC38_gets() - attempts to read a string from the pc38.
**                Always return ERR_NONE;
**-----------------------------------------------------------------------
*/
#if ANSI
int PC38_gets(int addr, char *mess, int len)
#else
int PC38_gets(addr, mess, len)
   int  addr;
   char * mess;
   int  len;
#endif
{
	int i, loop;

	/* PC38_outp8(addr+PC38_CONTROL_REG,0); */
	for (i=0; i<len; i++)
	{
		loop = 50;
		while ((PC38_inp8(addr+PC38_STATUS_REG) & PC38_IBF_BIT) == 0)
		{
			loop--;
			if(loop==1) PC38csleep(1);
			if(loop==0) 
			{
	         *mess = 0;
				return ERR_NONE;
			}
		}
      *mess = PC38_inp8(addr+PC38_DATA_REG);
		mess++;
	}
	*mess = 0;
	return ERR_NONE;
}

/*-----------------------------------------------------------------------
**  PC38_command() - Does a puts and get in a signal function call.
**-----------------------------------------------------------------------
*/
#if ANSI
int PC38_command( int addr, char * command, char * reply, int len_reply )
#else
int PC38_command( addr, command, reply, len_reply )
   int addr; 
   char * command; 
   char * reply; 
   int len_reply;
#endif
{
   int rc,
       l;
   char * r;
   char buf[40];

   /* write command */
   PC38_puts( addr, "\r");
   rc = PC38_puts( addr, command );
	PC38csleep(2);

   /* if caller didn't want reply, read into internal buffer */
   if( reply==NULL)
   {
      r = buf;
      l = sizeof(buf);
    }
    else
    {
       r = reply;
       l = len_reply;
       *r = 0;
    }

   /* read any reply */
   if( rc == ERR_NONE)
      PC38_gets( addr, r, l);

   return rc;
}

