/*****************************************************************
**  This file contains nice wrappers for iocntl() calls 
******************************************************************
*/
#include <ctype.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <oscalls.h>
 
#include "/sys/dheaders/pc38info.h"

#define ERR_IOCTL -1

int pc38get_setup( int fdpc38, unsigned long *Raddr)
{
   struct pc38parms_t pc38p;
   if( ioctl( fdpc38, PC38GET_SETUP, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   *Raddr = pc38p.i1;
   return pc38p.ret;
}

int pc38put_setup( int fdpc38, unsigned long addr)
{
   struct pc38parms_t pc38p;
   pc38p.i1 = addr;
   if( ioctl( fdpc38, PC38PUT_SETUP, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   return pc38p.ret;
}

int pc38df_get( int fdpc38, unsigned long *Rdf)
{
   struct pc38parms_t pc38p;
   if( ioctl( fdpc38, PC38DF_GET, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   *Rdf = pc38p.df;
   return pc38p.ret;
}

int pc38df_clear( int fdpc38, unsigned long df_bit )
{
   struct pc38parms_t pc38p;
   pc38p.i1 = df_bit;
   if( ioctl( fdpc38, PC38DF_CLEAR, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   return pc38p.ret;
}

int pc38puts( int fdpc38, char * s )
{
   struct pc38parms_t pc38p;
   pc38p.p1 = s;
   if( ioctl( fdpc38, PC38PUTS, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   return pc38p.ret;
}

int pc38gets( int fdpc38, char * s, int len )
{
   struct pc38parms_t pc38p;
   pc38p.p1 = s;
   pc38p.i1 = (unsigned long)len;
   if( ioctl( fdpc38, PC38GETS, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   return pc38p.ret;
}

int pc38command( int fdpc38, char * s, char* d, int len )
{
   struct pc38parms_t pc38p;
   pc38p.p1 = s;
   pc38p.p2 = d;
   pc38p.i1 = (unsigned long)len;
   if( ioctl( fdpc38, PC38COMMAND, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   return pc38p.ret;
}

int pc38get_status( int fdpc38, unsigned long *Rcontrol, unsigned long *Rstatus )
{
   struct pc38parms_t pc38p;
   if( ioctl( fdpc38, PC38GET_STATUS, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   *Rcontrol = pc38p.i1;
   *Rstatus  = pc38p.i2;
   return pc38p.ret;
}

int pc38outp8( int fdpc38, int port, int data)
{
   struct pc38parms_t pc38p;
 
   pc38p.i1 = port;
   pc38p.i2 = data;
   if( ioctl( fdpc38, PC38_OUTP8, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   return pc38p.ret;
}
 
int pc38inp8( int fdpc38, int port, int *Rdata)
{
   struct pc38parms_t pc38p;
 
   pc38p.i1 = port;
   if( ioctl( fdpc38, PC38_INP8, (char*)&pc38p) < 0)
      return ERR_IOCTL;
   *Rdata = pc38p.i2;
   return pc38p.ret;
}

