/************************************************* 
** pc38info.h 
** 
** Device Driver NASA IRTF
** 2680 Woodlawn Drive, Honolulu, HI, 96822
** 
** Author: Tony Denault
** 
*************************************************/

/* The pc38parms_t is used to pass argument to pc38 functions */
struct pc38parms_t 
{
   unsigned short addr; /* You supply I/O address of board */
   unsigned long i1;    /* Immediated value 1 */
   unsigned long i2;    /* Immediated value 2 */
   void * p1;           /* pointer #1         */
   void * p2;           /* pointer #2         */
   char * s1;           /* String pointer #1  */
   char * s2;           /* String pointer #2  */
   int  ret;            /* pc38d returns error code */
   int  df;             /* pc38d returns done flag */
};

/* The pc38info is used initial static information  */
struct pc38info_t 
{
   long addr;   /* memory mapped address I/O address of board */
};

/* iocntl commands */
#define PC38GET_SETUP    ( 1) 
#define PC38PUT_SETUP    ( 2) 
#define PC38DF_GET       ( 3) 
#define PC38DF_CLEAR     ( 4) 
#define PC38PUTS         ( 5) 
#define PC38GETS         ( 6) 
#define PC38COMMAND      ( 7) 
#define PC38TEST         ( 8) 
#define PC38GET_STATUS   ( 9) 

#define PC38_OUTP8       (10) 
#define PC38_INP8        (11) 

/* But assignment for done flag */
#define PC38_DONEX       0x01
#define PC38_DONEY       0x02
#define PC38_DONEZ       0x04
#define PC38_DONET       0x08
#define PC38_DONEU       0x10
#define PC38_DONEV       0x20
#define PC38_DONER       0x40
#define PC38_DONES       0x80

/* nice wrappers prototypes */
#if ANSI
	int pc38get_setup( int fdpc38, unsigned long *Raddr);
	int pc38put_setup( int fdpc38, unsigned long addr);
	int pc38df_get( int fdpc38, unsigned long *Rdf);
	int pc38df_clear( int fdpc38, unsigned long df_bit );
	int pc38puts( int fdpc38, char * s );
	int pc38gets( int fdpc38, char * s, int len );
	int pc38command( int fdpc38, char * s, char* d, int len );
	int pc38get_status( int fdpc38, unsigned long *Rcontrol, 
	   unsigned long *Rstatus); 
	int pc38outp8( int fdpc38, int port, int data);
	int pc38inp8( int fdpc38, int port, int *Rdata);
#else
	int pc38get_setup( );
	int pc38put_setup( );
	int pc38df_get( );
	int pc38df_clear( );
	int pc38puts( );
	int pc38gets( );
	int pc38command( );
	int pc38get_status( ); 
	int pc38outp8( );
	int pc38inp8( );
#endif
